from . import sedes
from .codec import (
    encode,
    decode,
    infer_sedes,
    descend,
    append,
    pop,
    compare_length,
    insert,
)
from .exceptions import (
    RLPException,
    EncodingError,
    DecodingError,
    SerializationError,
    DeserializationError,
)
from .lazy import decode_lazy, peek, LazyList
from .sedes import Serializable, make_immutable, make_mutable



import pytest
import rlp

def test_compare_length():
    data = rlp.encode([1,2,3,4,5])
    assert rlp.compare_length(data, 100) == -1
    assert rlp.compare_length(data, 5) == 0
    assert rlp.compare_length(data, 1) == 1

    data = rlp.encode([])
    assert rlp.compare_length(data, 100) == -1
    assert rlp.compare_length(data, 0) == 0
    assert rlp.compare_length(data, -1) == 1

def test_favor_short_string_form():
    data = rlp.utils.decode_hex('b8056d6f6f7365')
    with pytest.raises(rlp.exceptions.DecodingError):
        rlp.decode(data)

    data = rlp.utils.decode_hex('856d6f6f7365')
    assert rlp.decode(data) == b'moose'



# -*- coding: utf8 -*-
from __future__ import unicode_literals

import struct

import rlp


def test_bytearray():
    e = rlp.encode('abc')
    d = rlp.decode(e)
    d = rlp.decode(bytearray(e))


def test_bytearray_lazy():
    e = rlp.encode('abc')
    d = rlp.decode(e)
    d = rlp.decode_lazy(bytearray(e))


def test_bytearray_encode_decode():
    value = bytearray(b'asdf')
    encoded = rlp.utils.encode_hex(value)
    decoded = rlp.utils.decode_hex(encoded)

    assert value == decoded


def test_big_endian_to_int():
    assert rlp.utils.big_endian_to_int(b'\x00') == 0
    assert rlp.utils.big_endian_to_int(bytearray(b'\x00')) == 0

    value = struct.pack('>Q', 3141516)
    assert rlp.utils.big_endian_to_int(value) == 3141516
    assert rlp.utils.big_endian_to_int(bytearray(value)) == 3141516
